<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb_NO" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Mislykkes i å åpne kontoens database</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Innlogging utløpt, logg inn på nytt</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Kontoinnstillinger</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Skriv inn serveradressen</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 er ikke en gyldig serveradresse</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Mislykkes i å lagre kontoinformasjonen</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Mislykkes med å lagre endringene: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Oppdateringen av kontoinformasjonen gikk bra.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Serveradresse</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Kunne ikke frakoble synkroniseringen av denne kontoen: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>klikk for å åpne websiden</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>pro versjon</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Ingen konto</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Konto innstillinger</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logg inn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slette</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Legg til en konto</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>logg ut</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>ikke logget inn</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulær</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>email</source>
        <translation>epost</translation>
    </message>
    <message>
        <source>server</source>
        <translation>server</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>prøv på nytt</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Mislyktes i å få aktivitets-informasjon. Vennligst 1%</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Opplasting fulført</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Filen &quot;%1&quot;
ble lastet opp.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Fil &quot;%1&quot;
opplasting mislyktes</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Feilet i å generere en avatar folder</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Nedlastings-oppgaver</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>fjern alle gjennomførte oppgaver</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Ingen nedlasting-oppgaver akkurat nå</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Bibliotek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Sti</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Avslutt denne oppgaven</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>avslutt denne oppgaven</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Fjern denne oppgaven </translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Mislyktes i å avslutte denne oppgaven:

%1 </translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Mislyktes i å fjerne denne oppgaven:

 </translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimalisere</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukke</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Bibliotek</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Stjerne merket</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Aktiviteter</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>nåværende nedlastings-hastighet</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>nåværende opplastings-hastighet</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Vennligst lukk en folder for å synce</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>ingen server er tilknyttet</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>alle servere tilkoblet</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>noen servere er ikke tilkoblet</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Formulær</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimalisere</translation>
    </message>
    <message>
        <source>close</source>
        <translation>lukk</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>alternativt slipp en folder for å synkronisere</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>nedlastings-hastighet</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>nedover-pil</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>opplastings-hastighet</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>oppover-pil</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Feil ved oppretting av ccnet konfigurason</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Kan ikke opprette forhåndskonfigurert mappe &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>mislyktes i å lese %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Opprett et bibliotek</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vennligst velg en mappe</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Oppretter...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Klarte ikke å opprette krypteringsnøkkel for dette biblioteket</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Vennligst velg katalogen som skal synkroniseres</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Mappen %1 finnes ikke</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Skriv inn navnet</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Skriv inn passord</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Passordene stemmer ikke overens</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ukjent feil</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Kunne ikke legge til nedlastingsoppgave:
 %1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Kunne ikke opprette bibliotek på serveren:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>kryptert</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Gjenta passordet:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>status tekst</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 exited unexpectedly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Skriv inn passordet</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Synkroniser biblioteket &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Synkroniser mappe &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Synkroniser til mappe:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>eller</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>synkroniser med en eksisterende mappe</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>opprett en ny synkronisert mappe</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Synkroniser med eksisterende mappe:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Velg en mappe</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>Mappen finnes ikke</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Velg mappen du vil synkronisere</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Din organisasjon tillater ikke å legge et bibliotek utenfor  %1 mappe.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Konflikt med eksisterende fil &quot;%1&quot;. Vennligst velg en annen mappe.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Konflikt med eksisterende bibliotek &quot;%1&quot;, Vennligst velg en annen mappe.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>Mappen &quot;%1&quot; eksisterer allerede. Er du sikker på at du ønsker å synkronisere med den? (innhold vil bli slått sammen)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Trykk nei for å synkronisere med en annen mappe isteden</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Kan ikke finne et alternativt mappenavn</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Kunne ikke legge til nedlastingsoppgaven:
 %1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Kunne ikke hente nedlastingsinformasjon fra lokalt kodelager:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Nedlastingsbibliotek</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>velg...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Passord for dette biblioteket:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Endringsinformasjon</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Nye filer</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Slettede filer</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Endrede filer</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Nye mapper</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Slettede mapper</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Cloud filbehandler</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Fremover</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Last opp filer</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Last opp et bibliotek</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Du har ikke tillatelse til å laste opp filer i dette biblioteket</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Opprett en mappe</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Mappenavn</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Ugyldig mappenavn!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>Navnet &quot;%1&quot; er allerede i bruk.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>prøv på nytt</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Kunne ikke hente filinformasjon&lt;br/&gt;Vennligst %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Skriv navnet på filen å lagre til...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Kunne ikke fjerne filen &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Filen %1 eksisterer allerede.&lt;br/&gt;Ønsker du å overskrive den?&lt;br/&gt;&lt;small&gt;(Velg &quot;nei&quot; for laste opp med et annet navn).&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Kunne ikke laste ned filen: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Velg en fil å laste opp</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Velg en mappe å laste opp</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøpe</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Vil du virkelig slette disse elementene</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Kunne ikke opprette mappe</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Velg en fil å oppdatere %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Kunne ikke omdøpe</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Kunne ikke fjerne</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Kunne ikke dele</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Kan ikke lime inn filer fra samme mappe</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kunne ikke kopiere</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Kunne ikke flytte</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Kunne ikke opprette bibliotek!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Last opp</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Laster opp %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Laster ned %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 av %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File save failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Index progress request error %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Avbrutt operasjon</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>venter</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Intern serverfeil</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Sist endret</translation>
    </message>
    <message>
        <source>Modifier</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Lagre som...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Omdøpe</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Oppdater</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiere</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Kl&amp;ipp ut</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Lim inn</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>Av&amp;bryt nedlasting</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Synkroniser mappen</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Denne funksjonen er bare tilgjengelig i Pro-utgaven
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Kunne ikke opprette mapper</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Kunne ikke opprette midlertidige filer</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Kunne ikke skrive filen til disk</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Kunen ikke fjerne tidligere versjon av den nedlastede filen</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Kunne ikke flytte filen</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 Initialisering</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Vennligst velg en mappe</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Initialisering er ikke fullført. Vil du virkelig avslutte?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Mappen %1 eksisterer ikke</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Velg...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Kontrollerer ditt standard bibliotek...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Oppretter standardbiblioteket...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Kunne ikke opprette standardbiblioteket:

Serverversjonen må være 2.1 eller høyere for å støtte dette.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Kunne ikke hente standard bibliotek:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Kunne ikke opprette standard bibliotek:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Laster ned standard bibliotek...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Kunne ikke laste ned standard bibliotek:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>Standardbiblioteket er lastet ned.
Du kan trykke på &quot;åpne&quot;-knappen for å se på det.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Kunne ikke laste ned standard bibliotek: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Kunne ikke laste ned standard bibliotek:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Hopp over</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Kjør i bakgrunnen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Avslutte</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Last ned standard bibliotek</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogDirUploader</name>
    <message>
        <source>Upload log files failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files failed :%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully uploaded log files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogUploadProgressDialog</name>
    <message>
        <source>Compressing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Legg til en konto</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Logg inn pånytt</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Logger inn...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Nettverksfeil:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; SSL-sertifikatet på denne serveren er ikke bekreftet, fortsett likevel?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Skriv inn serveradressen</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 er en ugyldig serveradresse</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Skriv inn brukernavnet</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Skriv inn datamaskinnavnet</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Kunne ikke lagre nåværende konto</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Skriv inn passordet</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Feil e-postadresse eller passord</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Du har forsøkt å logge inn for ofte. Vennligst vent et minutt.</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Intern serverfeil</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Kunne ikke logge inn: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Kunne ikke logge inn</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For eksempel: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>eller http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>status tekst</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Datamaskinnavn:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>for eksempel Ola&apos;s bærbare</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logg inn</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Oppfrisk</translation>
    </message>
</context>
<context>
    <name>MessagePoller</name>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by another user. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file %1 is denied by folder permission setting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No permission to sync folder %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updates in read-only library %1 will not be uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Concurrent updates to file. File %1 is saved as conflict file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder %1 is moved to seafile-recycle-bin folder since it contains not-yet uploaded files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder for library %1 is removed or moved. The library is unsynced.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>synkronisert</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>indekserer filer</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>synkronisering initialieres</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>laster ned</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>Laster opp</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>synkroniseringen sammenstilles</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>venter på synkronisering</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>serveren er ikke tilkoblet</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>serveren autentiseres</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>automatisk synkronisering er avslått</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ukjent</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ukjent feil</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Tildelt lagringsplass er oppbrukt</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>Initialiserer....</translation>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>kobler til server...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>indekserer filer...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Oppretter mappe ....</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Slår sammen filendringer...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Utført</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Avbryter</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Avbrutt</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL-feil.</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Nettverksfeil: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Serverfeil</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>kunne ikke åpne sertifikatdatabasen</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 kunne ikke finne en applikasjon til å åpne filen %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Opprettet biblioteket &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Slettet bibliteket &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Omdøpe %1 til</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>Kunne ikke laste ned elementet &quot;%1&quot;</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>Kunne ikke kopiere</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Lagt til</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Slettet</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Fjernet</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Endret</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Omdøpt</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation>Flyttet</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Nytt bibliotek</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Fjernet bibliotek</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Omdøpt bibliotek</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Flyttet bibliotek</translation>
    </message>
    <message>
        <source>files</source>
        <translation>filer</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>mapper</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>og %1 flere</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Tilbakestilte biblioteket til statusen</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>Tilbakestilte filen&quot;%1&quot; til statusen %2.</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Gjenopprettet slettet bibliotek</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Endret biblioteksnavn eller beskrivelse</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>Akkurat nå</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 dag siden</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 dager siden</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 time siden</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 timer siden</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>1 minutt siden</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutter siden</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Ikke en del av sertifikatet&gt;</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PDF Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audio File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Excel Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file denied by folder permission setting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Client is already running</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try to resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not have write permission to the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No permission to sync this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed all items from trash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed items older than days %1 from trash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Published draft</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created draft</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted draft</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restored file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restored folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restored library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created or updated a file in a non-writable library or folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission denied on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Concurrent updates to file. File is saved as conflict file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A folder that may contain not-yet-uploaded files is moved to seafile-recycle-bin folder.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Bibliotek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Dette biblioteket er ikke lastet ned enda</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Feil: </translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>Kodelagerikon</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>Kodelagernavn</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>Tekstetikett</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Eier:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Sist endret:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>endringstid</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Lokal sti:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>Kodelagerstatus</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukke</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Dette biblioteket har ikke blitt lastet ned</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Nylig oppdatert</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Mine biblioteker</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Underbiblioteker</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Synkroniserte biblioteker</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Slå av automatisk synkronisering</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Slå på automatisk synkronisering</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>Vis &amp;detaljer</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Vis bibliotekets detaljer</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Synkroniser dette biblioteket</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Synkroniser dette biblioteket</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Nylig oppdatert</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>Synkroniser &amp;nå</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Synkroniser dette biblioteket umiddelbart</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;Avbryt nedlasting</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Avbryt nedlastingen av dette biblioteket</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Åpne mappe</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>åpne lokal mappe</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;frakoble synkronisering</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>Frakoble synkroniseringen av dette biblioteket</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Se i nettskyen</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>se dette biblioteket på seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>&amp;Åpne Cloud filbehandleren</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>åpne dette biblioteket i den innebygde Cloud filbehandleren</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>&amp;Synkroniser dette biblioteket pånytt</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>frakoble og synkroniser dette biblioteket pånytt</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Kunne ikke frakoble synkroniseringen av bibliotek &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Kunne ikke avbryte denne oppgaven:

 %1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>Nedlastingen har blitt avbrutt</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>Kunne ikke slette filen &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Kunne ikke laste opp filen: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>prøv på nytt</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Kunne ikke hente biblioteksinformasjonen&lt;br/&gt;Vennligst %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Advarsel:&lt;/b&gt; SSL-sertifikatet på denne serveren er ikke bekreftet, fortsett likevel?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Kunne ikke initialisere loggen: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to save client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to access %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>incorrect client id</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileExtensionHandler</name>
    <message>
        <source>Failed to get link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to lock file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unlock file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; is locked by %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get lock information for file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Internal Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Desktop Access Link:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>Unknown error</source>
        <translation>Ukjent feil</translation>
    </message>
    <message>
        <source>internal error: failed to connect to daemon</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Slå av automatisk synkronisering</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Slå på automatisk synkronisering</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Vis hovedvindu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Åpne &amp;loggmappen</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Vis applikasjonens &quot;om&quot; boks</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Hjelp på nett</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>automatisk synkronisering er avslått</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Laster opp</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Laster ned</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>noen servere er ikke tilkoblet</translation>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>upload %1 log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please login first</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Repair explorer extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully fixed sync status icons for Explorer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Faild to fix sync status icons for Explorer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>have some sync error</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Servernes tilkoblingsstatus</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>tilkoblet</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>frakoblet</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukke</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Skriv inn bibliotekspassord</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Skriv inn passordet for bibliotek %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Skriv inn passordet</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Feil passord</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ukjent feil</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP mellomtjener</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 mellomtjener</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Du har skiftet språk. Start om for å bruke det?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Skjul hovedvinduet ved oppstart</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Gi melding når bibliotekene er synkroniserte</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Aktiver synkronisering av midlertidige filer for MS Office/ LibreOffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Hastighetsbegrensing (KB/s) for nedlasting:</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Hastighetsbegrensning (KB/s) for opplasting: </translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grunnleggende</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Ikke frakoble synkronisering av et bibliotek automatisk</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Ikke frakoble synkroniseringen av et bibliotek automatisk når dens lokale mappe er fjernet eller utilgjengelig av andre årsaker.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Ikke frakoble synkroniseringen av et bibliotek når det ikke kan gjenfinnes på serveren</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Ikke frakoble synkronseringen av et bibliotek automatisk når det ikke gjenfinnes på serveren</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>Slå på FinderSync-utvidelsen</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Slå på Windows utforsker utvidelsen</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>Ikke verifiser serversertifikatet med HTTPS-sykronisering</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Språk (krever omstart)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Mellomtjenertype:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Vert:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Mellomtjeneren krever et passord</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Delingslenke</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Delingslenke:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopier til utklippstavlen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Ubekreftet tilkobling</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 bruker et et ugyldig sikkerhetssertifikat. Tilkoblingen kan være usikker. Ønsker du å fortsette?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Nåværende RSA-nøkkel fingeravtrykk er %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Tidligere RSA-nøkkel fingeravtrykk er %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Husk valget mitt</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Åpne denne filen</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>Se på &amp;Web</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>se denne filen på websiden</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>prøv på nytt</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Kunne ikke hente informasjon for favorittmarkerte filer&lt;br/&gt;Vennligst %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Du har ingen favorittmarkerte filer enda.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TwoFactorDialog</name>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>mText</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember this device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Avinstallere %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Ønsker du å fjerne %1 kontoinformasjonen?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Fjerner kontoinformasjon...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>tekst</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
</TS>